/*
 * Funambol is a mobile platform developed by Funambol, Inc. 
 * Copyright (C) 2003 - 2007 Funambol, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission 
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY FUNAMBOL, FUNAMBOL DISCLAIMS THE 
 * WARRANTY OF NON INFRINGEMENT  OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License 
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA.
 * 
 * You can contact Funambol, Inc. headquarters at 643 Bair Island Road, Suite 
 * 305, Redwood City, CA 94063, USA, or at email address info@funambol.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by Funambol" logo. If the display of the logo is not reasonably 
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by Funambol".
 */

package com.funambol.mail;

import com.funambol.util.Log;

import jmunit.framework.cldc10.AssertionFailedException;
import jmunit.framework.cldc10.TestCase;

/**
 * A JMUnit test class to check the functionality of the MIME parser
 */
public class MIMEProcessorTest extends TestCase {

    /**
     * The constructor. Please refer to the JMUnit documentation
     */
    public MIMEProcessorTest() {
        super(6, "MIMEProcessorTest");
        Log.setLogLevel(Log.DEBUG);
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage(String expectedResult, String contentType)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, result.getContentType());
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage2(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        try {
            assertEquals(expectedResult, result.getFrom().getEmail());// getName()
        } catch (MailException e) {
            e.printStackTrace();
        }
    }

    /**
     * Test of parseMailMessage method, of class com.funambol.mail.MIMEProcessor
     */
    public void testparseMailMessage3(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, result.getMessageId());
    }

    /**
     * @param expectedResult
     *            The content transfer encoding of the first body part
     *            (quoted-printable)
     */
    public void testparseMailMessage4(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        Multipart mp = (Multipart)result.getContent();
        BodyPart bp = mp.getBodyPart(0);
        String cte = bp.getHeader("content-transfer-encoding");

        assertEquals(expectedResult, cte);
    }

    /**
     * @param expectedResult
     *            The content type of the first body part (text/plain)
     */
    public void testparseMailMessage5(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        assertEquals(expectedResult, ((Multipart)result.getContent())
                .getBodyPart(0).getHeader("content-type"));
    }

    /**
     * @param expectedResult
     *            The content type of the second body part
     *            (application/x-pkcs7-signature)
     */
    public void testparseMailMessage6(String expectedResult)
            throws AssertionFailedException, MailException {

        MIMEProcessor instance = new MIMEProcessor();
        String rfc2822 = TestMessage.MULTIPART_JPEG;
        Message result = instance.parseMailMessage(rfc2822);

        
        
        assertEquals(expectedResult, ((Multipart)result.getContent())
                .getBodyPart(1).getHeader("content-type"));
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#setUp()
     */
    public void setUp() {
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#tearDown()
     */
    public void tearDown() {
    }

    /**
     * @see jmunit.framework.cldc11.TestCase#test(int)
     */
    public void test(int testNumber) throws Throwable {
        switch (testNumber) {

        case 0:
            testparseMailMessage("multipart/mixed", "content-type");
            break;

        case 1:
            testparseMailMessage2("giuseppe.garibaldi@platsch.com");
            break;

        case 2:
            testparseMailMessage3("c96b5e8f0611070513o3ec40fcbt24fdfed718856167@mail.gmail.com");
            break;
            
        case 3:
            testparseMailMessage4("quoted-printable");
            break;
            
        case 4:
            testparseMailMessage5("text/plain");
            break;
            
        case 5:
            testparseMailMessage6("image/jpeg");// application/octet-stream
            break;

        default:
            break;
        }
    }
}
